Power over Ethernet (PoE)

Configure PoE setting and display PoE Status.

Uninterrupted PoE

Keeps PoE devices powered on even when soft rebooting the switch.

CANCEL APPLY
Power Cycle Ports

Forcibly resets the PSE ports.

1 2 3 4 5
6 7 8 9 10
11 12 13 14 15
CANCEL APPLY

- SETTING

- STATUS

Port | Port Power | Power Mode

####

1 | Enable | 802.3at

Port Priority

Low

Power Limit Type

User

Power Limit (W)

30.0

Detection Type

IEEE802

Longer Detection Time

Disable

EDIT

Port Power

Port Priority
Power Mode
Power Limit Type
Power Limit (W)

(The range is from 3.0 watts to 30.0 watts with step increments of 0.2 watts)

Detection Type

Longer Detection Time

CANCEL APPLY

####

2 | Enable | 802.3at

Port Priority

Low

Power Limit Type

User

Power Limit (W)

30.0

Detection Type

IEEE802

Longer Detection Time

Disable

EDIT

Port Power

Port Priority
Power Mode
Power Limit Type
Power Limit (W)

(The range is from 3.0 watts to 30.0 watts with step increments of 0.2 watts)

Detection Type

Longer Detection Time

CANCEL APPLY

####

3 | Enable | 802.3at

Port Priority

Low

Power Limit Type

User

Power Limit (W)

30.0

Detection Type

IEEE802

Longer Detection Time

Disable

EDIT

Port Power

Port Priority
Power Mode
Power Limit Type
Power Limit (W)

(The range is from 3.0 watts to 30.0 watts with step increments of 0.2 watts)

Detection Type

Longer Detection Time

CANCEL APPLY

####

4 | Enable | 802.3at

Port Priority

Low

Power Limit Type

User

Power Limit (W)

30.0

Detection Type

IEEE802

Longer Detection Time

Disable

EDIT

Port Power

Port Priority
Power Mode
Power Limit Type
Power Limit (W)

(The range is from 3.0 watts to 30.0 watts with step increments of 0.2 watts)

Detection Type

Longer Detection Time

CANCEL APPLY

####

5 | Enable | 802.3at

Port Priority

Low

Power Limit Type

User

Power Limit (W)

30.0

Detection Type

IEEE802

Longer Detection Time

Disable

EDIT

Port Power

Port Priority
Power Mode
Power Limit Type
Power Limit (W)

(The range is from 3.0 watts to 30.0 watts with step increments of 0.2 watts)

Detection Type

Longer Detection Time

CANCEL APPLY

####

6 | Enable | 802.3at

Port Priority

Low

Power Limit Type

User

Power Limit (W)

30.0

Detection Type

IEEE802

Longer Detection Time

Disable

EDIT

Port Power

Port Priority
Power Mode
Power Limit Type
Power Limit (W)

(The range is from 3.0 watts to 30.0 watts with step increments of 0.2 watts)

Detection Type

Longer Detection Time

CANCEL APPLY

####

7 | Enable | 802.3at

Port Priority

Low

Power Limit Type

User

Power Limit (W)

30.0

Detection Type

IEEE802

Longer Detection Time

Disable

EDIT

Port Power

Port Priority
Power Mode
Power Limit Type
Power Limit (W)

(The range is from 3.0 watts to 30.0 watts with step increments of 0.2 watts)

Detection Type

Longer Detection Time

CANCEL APPLY

####

8 | Enable | 802.3at

Port Priority

Low

Power Limit Type

User

Power Limit (W)

30.0

Detection Type

IEEE802

Longer Detection Time

Disable

EDIT

Port Power

Port Priority
Power Mode
Power Limit Type
Power Limit (W)

(The range is from 3.0 watts to 30.0 watts with step increments of 0.2 watts)

Detection Type

Longer Detection Time

CANCEL APPLY

####

9 | Enable | 802.3at

Port Priority

Low

Power Limit Type

User

Power Limit (W)

30.0

Detection Type

IEEE802

Longer Detection Time

Disable

EDIT

Port Power

Port Priority
Power Mode
Power Limit Type
Power Limit (W)

(The range is from 3.0 watts to 30.0 watts with step increments of 0.2 watts)

Detection Type

Longer Detection Time

CANCEL APPLY

####

10 | Enable | 802.3at

Port Priority

Low

Power Limit Type

User

Power Limit (W)

30.0

Detection Type

IEEE802

Longer Detection Time

Disable

EDIT

Port Power

Port Priority
Power Mode
Power Limit Type
Power Limit (W)

(The range is from 3.0 watts to 30.0 watts with step increments of 0.2 watts)

Detection Type

Longer Detection Time

CANCEL APPLY

####

11 | Enable | 802.3at

Port Priority

Low

Power Limit Type

User

Power Limit (W)

30.0

Detection Type

IEEE802

Longer Detection Time

Disable

EDIT

Port Power

Port Priority
Power Mode
Power Limit Type
Power Limit (W)

(The range is from 3.0 watts to 30.0 watts with step increments of 0.2 watts)

Detection Type

Longer Detection Time

CANCEL APPLY

####

12 | Enable | 802.3at

Port Priority

Low

Power Limit Type

User

Power Limit (W)

30.0

Detection Type

IEEE802

Longer Detection Time

Disable

EDIT

Port Power

Port Priority
Power Mode
Power Limit Type
Power Limit (W)

(The range is from 3.0 watts to 30.0 watts with step increments of 0.2 watts)

Detection Type

Longer Detection Time

CANCEL APPLY

####

13 | Enable | 802.3at

Port Priority

Low

Power Limit Type

User

Power Limit (W)

30.0

Detection Type

IEEE802

Longer Detection Time

Disable

EDIT

Port Power

Port Priority
Power Mode
Power Limit Type
Power Limit (W)

(The range is from 3.0 watts to 30.0 watts with step increments of 0.2 watts)

Detection Type

Longer Detection Time

CANCEL APPLY

####

14 | Enable | 802.3at

Port Priority

Low

Power Limit Type

User

Power Limit (W)

30.0

Detection Type

IEEE802

Longer Detection Time

Disable

EDIT

Port Power

Port Priority
Power Mode
Power Limit Type
Power Limit (W)

(The range is from 3.0 watts to 30.0 watts with step increments of 0.2 watts)

Detection Type

Longer Detection Time

CANCEL APPLY

####

15 | Enable | 802.3at

Port Priority

Low

Power Limit Type

User

Power Limit (W)

30.0

Detection Type

IEEE802

Longer Detection Time

Disable

EDIT

Port Power

Port Priority
Power Mode
Power Limit Type
Power Limit (W)

(The range is from 3.0 watts to 30.0 watts with step increments of 0.2 watts)

Detection Type

Longer Detection Time

CANCEL APPLY

Port | Class | Status